@@ -3,10 +3,10 @@ var path = require('path');
 var config = {
   target: 'node',
   resolve: {
-    modules: ['/usr/lib/nodejs', '.'],
+  	modules: ['/usr/share/nodejs'],
   },
   resolveLoader: {
-    modules: ['/usr/lib/nodejs'],
+  	modules: ['/usr/share/nodejs'],
   },
   output: {
     libraryTarget: 'umd'
